package com.hp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.hp.user.client.entity.AccountVO;
import com.hp.user.client.service.AccountService;
import com.hp.user.client.service.MessageService;
import com.hp.user.service.constants.UserConstants;
import com.hp.user.service.dao.AccountMapper;
import com.hp.user.service.entity.Account;
import com.hp.user.service.redis.RedisOperation;

import redis.clients.jedis.Jedis;

import org.apache.commons.codec.binary.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 用户信息表 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class AccountServiceImpl implements AccountService {
	
	@Autowired
	private MessageService messageService;
	
	@Autowired
	private AccountMapper accountMapper;

	@Override
	public void login(String phone, String verificationCode) {
		try {
			//需要判断phone是否存在
			checkPhone(phone);
			String code = messageService.getVerificationCode(phone);
			if(StringUtils.equals(verificationCode, code)) {
				//登陆成功
			}else {
				//登陆失败
				//返回错误信息
			}
		}catch(Exception e) {
			
		}
	}

	@Override
	public Boolean checkPhone(String phone) {
		//不存在为true
		Boolean flage = true;
		try {
			
			QueryWrapper<Account> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("phone", phone);
			queryWrapper.eq("sys_deleted", 0);
			Integer count = accountMapper.selectCount(queryWrapper);
			if(count>0) {
				//表示手机以及存在，需要返回错误
				System.out.println("手机号已经存在");
				flage = false;
			}
			
		}catch(Exception e) {
			
		}
		return flage;
		
	}

	@Override
	public void register(AccountVO accountVo) {
		try {
			if(checkPhone(accountVo.getPhone())) {
				Account account = new Account();
				BeanUtils.copyProperties(accountVo, account);
				account.setUserId(IdWorker.getId());
				accountMapper.insert(account);
			}
		}catch(Exception e) {
			
		}
		
	}

	@Override
	public void bindWx(String userIdStr, String wxNumber) {
		try {
			Long userId = Long.parseLong(userIdStr);
			Account account = new Account();
			account.setUserId(userId);
			account.setWxNumber(wxNumber);
			accountMapper.updateById(account);
		}catch(Exception e) {
			
		}
		
	}

}
